@@ -126,13 +126,19 @@ class Hypervisor(object):
 		"""
 			Check for old qemu emulator.
 		"""
-		return self.system.bios_vendor == "Bochs"
+		if self.system.bios_vendor:
+			return self.system.bios_vendor == "Bochs"
+
+		return False
 
 	def __is_hypervisor_microsoft(self):
 		"""
 			Check for Microsoft hypervisor.
 		"""
-		return "Microsoft" in self.system.vendor
+		if self.system.vendor:
+			return "Microsoft" in self.system.vendor
+
+		return False
 
 
 if __name__ == "__main__":
